Learn R Programming

supclust (version 1.1-1)

plot.pelora: 2-Dimensional Visualization of Pelora's Output

Description

Yields a projection of the cases (for example \(n\) gene expression profiles) into the space of the first two gene group centroids that were identified by pelora.

Usage

# S3 method for pelora
plot(x, main = "2-Dimensional Projection Pelora's output",
            xlab = NULL, ylab = NULL, col = seq(x$yvals), ...)

Arguments

x

An R object of class "pelora", typically the result of pelora().

main

A character string, giving the title of the plot.

xlab

A character string, giving the annotation of the x-axis.

ylab

A character string, giving the annotation of the x-axis.

col

A numeric vector of length 2, coding the colors that will be used for plotting the class labels.

…

Further arguments passed to and from methods.

See Also

pelora, also for references.

Examples

Run this code
# NOT RUN {
 ## Running the examples of Pelora's help page
 example(pelora, echo = FALSE)
 plot(fit)
# }

Run the code above in your browser using DataLab